@@ -1,5 +1,5 @@
 /* LiquidRescaling Library
- * Copyright (C) 2007 Carlo Baldassi (the "Author") <carlobaldassi@gmail.com>.
+ * Copyright (C) 2007-2009 Carlo Baldassi (the "Author") <carlobaldassi@gmail.com>.
  * All Rights Reserved.
  *
  * This library implements the algorithm described in the paper
@@ -15,11 +15,10 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Lesser General Public License for more details.
- 
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/> 
- */
 
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/>
+ */
 
 #ifndef __LQR_ALL_H__
 #define __LQR_ALL_H__
@@ -30,12 +29,15 @@ G_BEGIN_DECLS
 
 #include <lqr/lqr_base.h>
 #include <lqr/lqr_gradient.h>
+#include <lqr/lqr_rwindow.h>
+#include <lqr/lqr_energy.h>
 #include <lqr/lqr_cursor.h>
 #include <lqr/lqr_progress.h>
 #include <lqr/lqr_vmap.h>
 #include <lqr/lqr_vmap_list.h>
 #include <lqr/lqr_carver_list.h>
 #include <lqr/lqr_carver_bias.h>
+#include <lqr/lqr_carver_rigmask.h>
 #include <lqr/lqr_carver.h>
 
 G_END_DECLS
